@@ -1,4 +1,4 @@
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 import sys, os
 from time import sleep
@@ -27,3 +27,5 @@ def slow_print(*strings, time = 0.045, sep = ' ', end = '\n', file = sys.stdout)
 	file.flush()
 	file.write(end)
 	file.flush()
+def wait(time = 1):
+  sleep(time)
\ No newline at end of file
